# -*- coding: utf-8 -*-
#
# This file is part of Flask-CeleryExt
# Copyright (C) 2017 CERN.
#
# Flask-CeleryExt is free software; you can redistribute it and/or modify it
# under the terms of the Revised BSD License; see LICENSE file for more
# details.

"""Mapping of Celery v3 to v4 configuration names."""

from __future__ import absolute_import, print_function

V3TOV4MAPPING = {
    'CELERY_ACCEPT_CONTENT': 'CELERY_ACCEPT_CONTENT',
    'CELERY_BEAT_MAX_LOOP_INTERVAL': 'CELERYBEAT_MAX_LOOP_INTERVAL',
    'CELERY_BEAT_SCHEDULE': 'CELERYBEAT_SCHEDULE',
    'CELERY_BEAT_SCHEDULER': 'CELERYBEAT_SCHEDULER',
    'CELERY_BEAT_SCHEDULE_FILENAME': 'CELERYBEAT_SCHEDULE_FILENAME',
    'CELERY_BEAT_SYNC_EVERY': 'CELERYBEAT_SYNC_EVERY',
    'CELERY_BROKER_CONNECTION_MAX_RETRIES': 'BROKER_CONNECTION_MAX_RETRIES',
    'CELERY_BROKER_CONNECTION_RETRY': 'BROKER_CONNECTION_RETRY',
    'CELERY_BROKER_CONNECTION_TIMEOUT': 'BROKER_CONNECTION_TIMEOUT',
    'CELERY_BROKER_FAILOVER_STRATEGY': 'BROKER_FAILOVER_STRATEGY',
    'CELERY_BROKER_HEARTBEAT': 'BROKER_HEARTBEAT',
    'CELERY_BROKER_LOGIN_METHOD': 'BROKER_LOGIN_METHOD',
    'CELERY_BROKER_POOL_LIMIT': 'BROKER_POOL_LIMIT',
    'CELERY_BROKER_TRANSPORT': 'BROKER_TRANSPORT',
    'CELERY_BROKER_TRANSPORT_OPTIONS': 'BROKER_TRANSPORT_OPTIONS',
    'CELERY_BROKER_URL': 'BROKER_URL',
    'CELERY_BROKER_USE_SSL': 'BROKER_USE_SSL',
    'CELERY_CACHE_BACKEND': 'CELERY_CACHE_BACKEND',
    'CELERY_CACHE_BACKEND_OPTIONS': 'CELERY_CACHE_BACKEND_OPTIONS',
    'CELERY_CASSANDRA_ENTRY_TTL': 'CASSANDRA_ENTRY_TTL',
    'CELERY_CASSANDRA_KEYSPACE': 'CASSANDRA_KEYSPACE',
    'CELERY_CASSANDRA_PORT': 'CASSANDRA_PORT',
    'CELERY_CASSANDRA_READ_CONSISTENCY': 'CASSANDRA_READ_CONSISTENCY',
    'CELERY_CASSANDRA_SERVERS': 'CASSANDRA_SERVERS',
    'CELERY_CASSANDRA_TABLE': 'CASSANDRA_COLUMN_FAMILY',
    'CELERY_CASSANDRA_WRITE_CONSISTENCY': 'CASSANDRA_WRITE_CONSISTENCY',
    'CELERY_COUCHBASE_BACKEND_SETTINGS': 'CELERY_COUCHBASE_BACKEND_SETTINGS',
    'CELERY_DATABASE_DB_NAMES': 'CELERY_RESULT_DB_TABLE_NAMES',
    'CELERY_DATABASE_ENGINE_OPTIONS': 'CELERY_RESULT_ENGINE_OPTIONS',
    'CELERY_DATABASE_SHORT_LIVED_SESSIONS': 'CELERY_DB_SHORT_LIVED_SESSIONS',
    'CELERY_ENABLE_UTC': 'CELERY_ENABLE_UTC',
    'CELERY_EVENT_QUEUE_EXPIRES': 'CELERY_EVENT_QUEUE_EXPIRES',
    'CELERY_EVENT_QUEUE_PREFIX': 'CELERY_EVENT_QUEUE_PREFIX',
    'CELERY_EVENT_QUEUE_TTL': 'CELERY_EVENT_QUEUE_TTL',
    'CELERY_EVENT_SERIALIZER': 'CELERY_EVENT_SERIALIZER',
    'CELERY_IMPORTS': 'CELERY_IMPORTS',
    'CELERY_INCLUDE': 'CELERY_INCLUDE',
    'CELERY_MONGODB_BACKEND_SETTINGS': 'CELERY_MONGODB_BACKEND_SETTINGS',
    'CELERY_REDIS_DB': 'CELERY_REDIS_DB',
    'CELERY_REDIS_HOST': 'CELERY_REDIS_HOST',
    'CELERY_REDIS_MAX_CONNECTIONS': 'CELERY_REDIS_MAX_CONNECTIONS',
    'CELERY_REDIS_PASSWORD': 'CELERY_REDIS_PASSWORD',
    'CELERY_REDIS_PORT': 'CELERY_REDIS_PORT',
    'CELERY_RESULT_BACKEND': 'CELERY_RESULT_BACKEND',
    'CELERY_RESULT_CACHE_MAX': 'CELERY_MAX_CACHED_RESULTS',
    'CELERY_RESULT_COMPRESSION': 'CELERY_MESSAGE_COMPRESSION',
    'CELERY_RESULT_EXCHANGE': 'CELERY_RESULT_EXCHANGE',
    'CELERY_RESULT_EXCHANGE_TYPE': 'CELERY_RESULT_EXCHANGE_TYPE',
    'CELERY_RESULT_EXPIRES': 'CELERY_TASK_RESULT_EXPIRES',
    'CELERY_RESULT_PERSISTENT': 'CELERY_RESULT_PERSISTENT',
    'CELERY_RESULT_SERIALIZER': 'CELERY_RESULT_SERIALIZER',
    'CELERY_SECURITY_CERTIFICATE': 'CELERY_SECURITY_CERTIFICATE',
    'CELERY_SECURITY_CERT_STORE': 'CELERY_SECURITY_CERT_STORE',
    'CELERY_SECURITY_KEY': 'CELERY_SECURITY_KEY',
    'CELERY_TASK_ACKS_LATE': 'CELERY_ACKS_LATE',
    'CELERY_TASK_ALWAYS_EAGER': 'CELERY_ALWAYS_EAGER',
    'CELERY_TASK_ANNOTATIONS': 'CELERY_ANNOTATIONS',
    'CELERY_TASK_COMPRESSION': 'CELERY_MESSAGE_COMPRESSION',
    'CELERY_TASK_CREATE_MISSING_QUEUES': 'CELERY_CREATE_MISSING_QUEUES',
    'CELERY_TASK_DEFAULT_DELIVERY_MODE': 'CELERY_DEFAULT_DELIVERY_MODE',
    'CELERY_TASK_DEFAULT_EXCHANGE': 'CELERY_DEFAULT_EXCHANGE',
    'CELERY_TASK_DEFAULT_EXCHANGE_TYPE': 'CELERY_DEFAULT_EXCHANGE_TYPE',
    'CELERY_TASK_DEFAULT_QUEUE': 'CELERY_DEFAULT_QUEUE',
    'CELERY_TASK_DEFAULT_RATE_LIMIT': 'CELERY_DEFAULT_RATE_LIMIT',
    'CELERY_TASK_DEFAULT_ROUTING_KEY': 'CELERY_DEFAULT_ROUTING_KEY',
    'CELERY_TASK_EAGER_PROPAGATES': 'CELERY_EAGER_PROPAGATES_EXCEPTIONS',
    'CELERY_TASK_IGNORE_RESULT': 'CELERY_IGNORE_RESULT',
    'CELERY_TASK_PUBLISH_RETRY': 'CELERY_TASK_PUBLISH_RETRY',
    'CELERY_TASK_PUBLISH_RETRY_POLICY': 'CELERY_TASK_PUBLISH_RETRY_POLICY',
    'CELERY_TASK_QUEUES': 'CELERY_QUEUES',
    'CELERY_TASK_ROUTES': 'CELERY_ROUTES',
    'CELERY_TASK_SEND_SENT_EVENT': 'CELERY_SEND_TASK_SENT_EVENT',
    'CELERY_TASK_SERIALIZER': 'CELERY_TASK_SERIALIZER',
    'CELERY_TASK_SOFT_TIME_LIMIT': 'CELERYD_TASK_SOFT_TIME_LIMIT',
    'CELERY_TASK_TIME_LIMIT': 'CELERYD_TASK_TIME_LIMIT',
    'CELERY_TASK_TRACK_STARTED': 'CELERY_TRACK_STARTED',
    'CELERY_TIMEZONE': 'CELERY_TIMEZONE',
    'CELERY_WORKER_AGENT': 'CELERYD_AGENT',
    'CELERY_WORKER_AUTOSCALER': 'CELERYD_AUTOSCALER',
    'CELERY_WORKER_CONCURRENCY': 'CELERYD_CONCURRENCY',
    'CELERY_WORKER_CONSUMER': 'CELERYD_CONSUMER',
    'CELERY_WORKER_DIRECT': 'CELERY_WORKER_DIRECT',
    'CELERY_WORKER_DISABLE_RATE_LIMITS': 'CELERY_DISABLE_RATE_LIMITS',
    'CELERY_WORKER_ENABLE_REMOTE_CONTROL': 'CELERY_ENABLE_REMOTE_CONTROL',
    'CELERY_WORKER_HIJACK_ROOT_LOGGER': 'CELERYD_HIJACK_ROOT_LOGGER',
    'CELERY_WORKER_LOG_COLOR': 'CELERYD_LOG_COLOR',
    'CELERY_WORKER_LOG_FORMAT': 'CELERYD_LOG_FORMAT',
    'CELERY_WORKER_LOST_WAIT': 'CELERYD_WORKER_LOST_WAIT',
    'CELERY_WORKER_MAX_TASKS_PER_CHILD': 'CELERYD_MAX_TASKS_PER_CHILD',
    'CELERY_WORKER_POOL': 'CELERYD_POOL',
    'CELERY_WORKER_POOL_PUTLOCKS': 'CELERYD_POOL_PUTLOCKS',
    'CELERY_WORKER_POOL_RESTARTS': 'CELERYD_POOL_RESTARTS',
    'CELERY_WORKER_PREFETCH_MULTIPLIER': 'CELERYD_PREFETCH_MULTIPLIER',
    'CELERY_WORKER_REDIRECT_STDOUTS': 'CELERYD_REDIRECT_STDOUTS',
    'CELERY_WORKER_REDIRECT_STDOUTS_LEVEL': 'CELERYD_REDIRECT_STDOUTS_LEVEL',
    'CELERY_WORKER_SEND_TASK_EVENTS': 'CELERYD_SEND_EVENTS',
    'CELERY_WORKER_STATE_DB': 'CELERYD_STATE_DB',
    'CELERY_WORKER_TASK_LOG_FORMAT': 'CELERYD_TASK_LOG_FORMAT',
    'CELERY_WORKER_TIMER': 'CELERYD_TIMER',
    'CELERY_WORKER_TIMER_PRECISION': 'CELERYD_TIMER_PRECISION'
}
